@@ -11,7 +11,7 @@ from types import ModuleType
 import argparse
 argcomplete: Union[None, ModuleType] = None
 try:
-    import argcomplete
+    import argcomplete # type: ignore
 except ImportError as e:
     pass # already set to None by default above
 
@@ -226,7 +226,7 @@ def setPref(config, comp_name, raw_val) -> bool:
     logging.debug(f"valStr:{raw_val} val:{val}")
 
     if snake_name == "wifi_psk" and len(str(raw_val)) < 8:
-        print(f"Warning: network.wifi_psk must be 8 or more characters.")
+        print("Warning: network.wifi_psk must be 8 or more characters.")
         return False
 
     enumType = pref.enum_type
@@ -483,6 +483,7 @@ def onConnected(interface):
             if checkChannel(interface, channelIndex):
                 print(
                     f"Sending text message {args.sendtext} to {args.dest} on channelIndex:{channelIndex}"
+                    f" {'using PRIVATE_APP port' if args.private else ''}"
                 )
                 interface.sendText(
                     args.sendtext,
@@ -490,6 +491,7 @@ def onConnected(interface):
                     wantAck=True,
                     channelIndex=channelIndex,
                     onResponse=interface.getNode(args.dest, False, **getNode_kwargs).onAckNak,
+                    portNum=portnums_pb2.PortNum.PRIVATE_APP if args.private else portnums_pb2.PortNum.TEXT_MESSAGE_APP
                 )
             else:
                 meshtastic.util.our_exit(
@@ -595,6 +597,7 @@ def onConnected(interface):
 
             # Handle the int/float/bool arguments
             pref = None
+            fields = set()
             for pref in args.set:
                 found = False
                 field = splitCompoundName(pref[0].lower())[0]
@@ -607,11 +610,19 @@ def onConnected(interface):
                             )
                         found = setPref(config, pref[0], pref[1])
                         if found:
+                            fields.add(field)
                             break
 
             if found:
                 print("Writing modified preferences to device")
-                node.writeConfig(field)
+                if len(fields) > 1:
+                    print("Using a configuration transaction")
+                    node.beginSettingsTransaction()
+                for field in fields:
+                    print(f"Writing {field} configuration to device")
+                    node.writeConfig(field)
+                if len(fields) > 1:
+                    node.commitSettingsTransaction()
             else:
                 if mt_config.camel_case:
                     print(
@@ -714,12 +725,16 @@ def onConnected(interface):
             closeNow = True
             export_config(interface)
 
-        if args.seturl:
+        if args.ch_set_url:
             closeNow = True
-            interface.getNode(args.dest, **getNode_kwargs).setURL(args.seturl)
+            interface.getNode(args.dest, **getNode_kwargs).setURL(args.ch_set_url, addOnly=False)
 
         # handle changing channels
 
+        if args.ch_add_url:
+            closeNow = True
+            interface.getNode(args.dest, **getNode_kwargs).setURL(args.ch_add_url, addOnly=True)
+
         if args.ch_add:
             channelIndex = mt_config.channel_index
             if channelIndex is not None:
@@ -921,7 +936,11 @@ def onConnected(interface):
             if args.dest != BROADCAST_ADDR:
                 print("Showing node list of a remote node is not supported.")
                 return
-            interface.showNodes()
+            interface.showNodes(True, args.show_fields)
+
+        if args.show_fields and not args.nodes:
+            print("--show-fields can only be used with --nodes")
+            return
 
         if args.qr or args.qr_all:
             closeNow = True
@@ -1245,6 +1264,19 @@ def common():
                         noProto=args.noproto,
                         noNodes=args.no_nodes,
                     )
+                except FileNotFoundError:
+                    # Handle the case where the serial device is not found
+                    message = (
+                        f"File Not Found Error:\n"
+                    )
+                    message += f"  The serial device at '{args.port}' was not found.\n"
+                    message += "  Please check the following:\n"
+                    message += "    1. Is the device connected properly?\n"
+                    message += "    2. Is the correct serial port specified?\n"
+                    message += "    3. Are the necessary drivers installed?\n"
+                    message += "    4. Are you using a **power-only USB cable**? A power-only cable cannot transmit data.\n"
+                    message += "       Ensure you are using a **data-capable USB cable**.\n"
+                    meshtastic.util.our_exit(message, 1)
                 except PermissionError as ex:
                     username = os.getlogin()
                     message = "Permission Error:\n"
@@ -1255,6 +1287,12 @@ def common():
                     message += "  After running that command, log out and re-login for it to take effect.\n"
                     message += f"Error was:{ex}"
                     meshtastic.util.our_exit(message)
+                except OSError as ex:
+                    message = f"OS Error:\n"
+                    message += "  The serial device couldn't be opened, it might be in use by another process.\n"
+                    message += "  Please close any applications or webpages that may be using the device and try again.\n"
+                    message += f"\nOriginal error: {ex}"
+                    meshtastic.util.our_exit(message)
                 if client.devPath is None:
                     try:
                         client = meshtastic.tcp_interface.TCPInterface(
@@ -1342,7 +1380,8 @@ def addSelectionArgs(parser: argparse.ArgumentParser) -> argparse.ArgumentParser
 
     group.add_argument(
         "--dest",
-        help="The destination node id for any sent commands, if not set '^all' or '^local' is assumed as appropriate",
+        help="The destination node id for any sent commands. If not set '^all' or '^local' is assumed."
+        "Use the node ID with a '!' or '0x' prefix or the node number.",
         default=None,
         metavar="!xxxxxxxx",
     )
@@ -1387,7 +1426,7 @@ def addConfigArgs(parser: argparse.ArgumentParser) -> argparse.ArgumentParser:
         "--get",
         help=(
             "Get a preferences field. Use an invalid field such as '0' to get a list of all fields."
-            " Can use either snake_case or camelCase format. (ex: 'ls_secs' or 'lsSecs')"
+            " Can use either snake_case or camelCase format. (ex: 'power.ls_secs' or 'power.lsSecs')"
         ),
         nargs=1,
         action="append",
@@ -1396,7 +1435,11 @@ def addConfigArgs(parser: argparse.ArgumentParser) -> argparse.ArgumentParser:
 
     group.add_argument(
         "--set",
-        help="Set a preferences field. Can use either snake_case or camelCase format. (ex: 'ls_secs' or 'lsSecs')",
+        help=(
+            "Set a preferences field. Can use either snake_case or camelCase format."
+            " (ex: 'power.ls_secs' or 'power.lsSecs'). May be less reliable when"
+            " setting properties from more than one configuration section."
+        ),
         nargs=2,
         action="append",
         metavar=("FIELD", "VALUE"),
@@ -1489,7 +1532,20 @@ def addConfigArgs(parser: argparse.ArgumentParser) -> argparse.ArgumentParser:
         "--set-ham", help="Set licensed Ham ID and turn off encryption", action="store"
     )
 
-    group.add_argument("--seturl", help="Set a channel URL", action="store")
+    group.add_argument(
+        "--ch-set-url", "--seturl",
+        help="Set all channels and set LoRa config from a supplied URL",
+        metavar="URL",
+        action="store"
+    )
+
+    group.add_argument(
+        "--ch-add-url",
+        help="Add secondary channels and set LoRa config from a supplied URL",
+        metavar="URL",
+        default=None,
+    )
+
 
     return parser
 
@@ -1627,6 +1683,13 @@ def addLocalActionArgs(parser: argparse.ArgumentParser) -> argparse.ArgumentPars
         action="store_true",
     )
 
+    group.add_argument(
+        "--show-fields",
+        help="Specify fields to show (comma-separated) when using --nodes",
+        type=lambda s: s.split(','),
+        default=None
+    )
+
     return parser
 
 def addRemoteActionArgs(parser: argparse.ArgumentParser) -> argparse.ArgumentParser:
@@ -1638,15 +1701,21 @@ def addRemoteActionArgs(parser: argparse.ArgumentParser) -> argparse.ArgumentPar
 
     group.add_argument(
         "--sendtext",
-        help="Send a text message. Can specify a destination '--dest' and/or channel index '--ch-index'.",
+        help="Send a text message. Can specify a destination '--dest', use of PRIVATE_APP port '--private', and/or channel index '--ch-index'.",
         metavar="TEXT",
     )
 
+    group.add_argument(
+        "--private",
+        help="Optional argument for sending text messages to the PRIVATE_APP port. Use in combination with --sendtext.",
+        action="store_true"
+    )
+
     group.add_argument(
         "--traceroute",
         help="Traceroute from connected node to a destination. "
         "You need pass the destination ID as argument, like "
-        "this: '--traceroute !ba4bf9d0' "
+        "this: '--traceroute !ba4bf9d0' | '--traceroute 0xba4bf9d0'"
         "Only nodes with a shared channel can be traced.",
         metavar="!xxxxxxxx",
     )
@@ -1727,27 +1796,32 @@ def addRemoteAdminArgs(parser: argparse.ArgumentParser) -> argparse.ArgumentPars
 
     group.add_argument(
         "--remove-node",
-        help="Tell the destination node to remove a specific node from its DB, by node number or ID",
+        help="Tell the destination node to remove a specific node from its NodeDB. "
+        "Use the node ID with a '!' or '0x' prefix or the node number.",
         metavar="!xxxxxxxx"
     )
     group.add_argument(
         "--set-favorite-node",
-        help="Tell the destination node to set the specified node to be favorited on the NodeDB on the devicein its DB, by number or ID",
+        help="Tell the destination node to set the specified node to be favorited on the NodeDB. "
+        "Use the node ID with a '!' or '0x' prefix or the node number.",
         metavar="!xxxxxxxx"
     )
     group.add_argument(
         "--remove-favorite-node",
-        help="Tell the destination node to set the specified node to be un-favorited on the NodeDB on the device, by number or ID",
+        help="Tell the destination node to set the specified node to be un-favorited on the NodeDB. "
+        "Use the node ID with a '!' or '0x' prefix or the node number.",
         metavar="!xxxxxxxx"
     )
     group.add_argument(
         "--set-ignored-node",
-        help="Tell the destination node to set the specified node to be ignored on the NodeDB on the devicein its DB, by number or ID",
+        help="Tell the destination node to set the specified node to be ignored on the NodeDB. "
+        "Use the node ID with a '!' or '0x' prefix or the node number.",
         metavar="!xxxxxxxx"
     )
     group.add_argument(
         "--remove-ignored-node",
-        help="Tell the destination node to set the specified node to be un-ignored on the NodeDB on the device, by number or ID",
+        help="Tell the destination node to set the specified node to be un-ignored on the NodeDB. "
+        "Use the node ID with a '!' or '0x' prefix or the node number.",
         metavar="!xxxxxxxx"
     )
     group.add_argument(
