@@ -408,8 +408,8 @@ def test_main_nodes(capsys):
 
     iface = MagicMock(autospec=SerialInterface)
 
-    def mock_showNodes():
-        print("inside mocked showNodes")
+    def mock_showNodes(includeSelf, showFields):
+        print(f"inside mocked showNodes: {includeSelf} {showFields}")
 
     iface.showNodes.side_effect = mock_showNodes
     with patch("meshtastic.serial_interface.SerialInterface", return_value=iface) as mo:
@@ -593,10 +593,10 @@ def test_main_sendtext(capsys):
     iface = MagicMock(autospec=SerialInterface)
 
     def mock_sendText(
-        text, dest, wantAck=False, wantResponse=False, onResponse=None, channelIndex=0
+        text, dest, wantAck=False, wantResponse=False, onResponse=None, channelIndex=0, portNum=0
     ):
         print("inside mocked sendText")
-        print(f"{text} {dest} {wantAck} {wantResponse} {channelIndex}")
+        print(f"{text} {dest} {wantAck} {wantResponse} {channelIndex} {portNum}")
 
     iface.sendText.side_effect = mock_sendText
 
@@ -620,10 +620,10 @@ def test_main_sendtext_with_channel(capsys):
     iface = MagicMock(autospec=SerialInterface)
 
     def mock_sendText(
-        text, dest, wantAck=False, wantResponse=False, onResponse=None, channelIndex=0
+        text, dest, wantAck=False, wantResponse=False, onResponse=None, channelIndex=0, portNum=0
     ):
         print("inside mocked sendText")
-        print(f"{text} {dest} {wantAck} {wantResponse} {channelIndex}")
+        print(f"{text} {dest} {wantAck} {wantResponse} {channelIndex} {portNum}")
 
     iface.sendText.side_effect = mock_sendText
 
