@@ -254,6 +254,16 @@ class Timeout:
             time.sleep(self.sleepInterval)
         return False
 
+    def waitForWaypoint(self, acknowledgment) -> bool:
+        """Block until waypoint response is received. Returns True if waypoint response has been received."""
+        self.reset()
+        while time.time() < self.expireTime:
+            if getattr(acknowledgment, "receivedWaypoint", None):
+                acknowledgment.reset()
+                return True
+            time.sleep(self.sleepInterval)
+        return False
+
 class Acknowledgment:
     "A class that records which type of acknowledgment was just received, if any."
 
@@ -265,6 +275,7 @@ class Acknowledgment:
         self.receivedTraceRoute = False
         self.receivedTelemetry = False
         self.receivedPosition = False
+        self.receivedWaypoint = False
 
     def reset(self) -> None:
         """reset"""
@@ -274,6 +285,7 @@ class Acknowledgment:
         self.receivedTraceRoute = False
         self.receivedTelemetry = False
         self.receivedPosition = False
+        self.receivedWaypoint = False
 
 
 class DeferredExecution:
@@ -521,15 +533,15 @@ def is_windows11() -> bool:
     """Detect if Windows 11"""
     is_win11: bool = False
     if platform.system() == "Windows":
-        if float(platform.release()) >= 10.0:
-            patch = platform.version().split(".")[2]
-            # in case they add some number suffix later, just get first 5 chars of patch
-            patch = patch[:5]
-            try:
+        try:
+            if float(platform.release()) >= 10.0:
+                patch = platform.version().split(".")[2]
+                # in case they add some number suffix later, just get first 5 chars of patch
+                patch = patch[:5]
                 if int(patch) >= 22000:
                     is_win11 = True
-            except Exception as e:
-                print(f"problem detecting win11 e:{e}")
+        except Exception as e:
+            print(f"problem detecting win11 e:{e}")
     return is_win11
 
 
